unit fuSQLBuilderOptions;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Spin, ExtCtrls, acAST;

type
  TfmSQLBuilderOptions = class(TForm)
    pnlGroup1: TPanel;
    bvGroup1: TBevel;
    lbGroup1: TLabel;
    pnlBottom: TPanel;
    bvBottom: TBevel;
    pnlGroup6: TPanel;
    bvGroup6: TBevel;
    lbGroup6: TLabel;
    pnlGroup5: TPanel;
    bvGroup5: TBevel;
    lbGroup5: TLabel;
    pnlGroup4: TPanel;
    bvGroup4: TBevel;
    lbGroup4: TLabel;
    pnlGroup3: TPanel;
    bvGroup3: TBevel;
    lbGroup3: TLabel;
    pnlGroup2: TPanel;
    bvGroup2: TBevel;
    lbGroup2: TLabel;
    bCancel: TButton;
    bOk: TButton;
    pnlCommonOptions: TPanel;
    pnlSelectOptions: TPanel;
    pnlFromOptions: TPanel;
    pnlGroupByOptions: TPanel;
    pnlWhereOptions: TPanel;
    pnlHavingOptions: TPanel;
    checkPartsFromNewLines: TCheckBox;
    checkNewLineAfterKeywords: TCheckBox;
    editPartIndent: TSpinEdit;
    lbPartIndent: TLabel;
    checkNewLineAfterSelectItem: TCheckBox;
    checkNewLineAfterDatasource: TCheckBox;
    checkNewLineWhereTop: TCheckBox;
    checkNewLineAfterGroupItem: TCheckBox;
    checkNewLineHavingTop: TCheckBox;
    checkNewLineAfterJoin: TCheckBox;
    checkNewLineWhereRest: TCheckBox;
    lbWhereIndent: TLabel;
    editWhereIndent: TSpinEdit;
    checkNewLineHavingRest: TCheckBox;
    lbHavingIndent: TLabel;
    editHavingIndent: TSpinEdit;
    editGlobalIndent: TSpinEdit;
    lbGlobalIndant: TLabel;
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormShow(Sender: TObject);
    procedure FormHide(Sender: TObject);
    procedure checkNewLineWhereTopClick(Sender: TObject);
    procedure checkNewLineWhereRestClick(Sender: TObject);
    procedure checkNewLineHavingTopClick(Sender: TObject);
    procedure checkNewLineHavingRestClick(Sender: TObject);
  private
    { Private declarations }
	 procedure LoadSettings;
	 procedure SaveSettings;
  public
    { Public declarations }
	 SelectFormat: TSQLBuilderSelectFormat;
  end;

var
  fmSQLBuilderOptions: TfmSQLBuilderOptions;

implementation

{$R *.dfm}

procedure TfmSQLBuilderOptions.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
	Action := caHide;
end;

procedure TfmSQLBuilderOptions.FormShow(Sender: TObject);
begin
	LoadSettings;
end;

procedure TfmSQLBuilderOptions.FormHide(Sender: TObject);
begin
	SaveSettings;
end;

procedure TfmSQLBuilderOptions.LoadSettings;
begin
	with SelectFormat do begin

		checkPartsFromNewLines.Checked := MainPartsFromNewLine;
		checkNewLineAfterKeywords.Checked := NewLineAfterPartKeywords;
		editPartIndent.Value := IndentInPart;
		editGlobalIndent.Value := IndentGlobal;

		checkNewLineAfterSelectItem.Checked := SelectListFormat.NewLineAfterItem;

		checkNewLineAfterDatasource.Checked := FromClauseFormat.NewLineAfterDatasource;
		checkNewLineAfterJoin.Checked := FromClauseFormat.NewLineAfterJoin;

		checkNewLineWhereTop.Checked :=
			WhereFormat.NewLineAfter in [nlAllLogical, nlTopmostOr, nlTopmostLogical];
		checkNewLineWhereTopClick(nil);
		checkNewLineWhereRest.Checked := WhereFormat.NewLineAfter = nlAllLogical;
		checkNewLineWhereRestClick(nil);
		editWhereIndent.Value := WhereFormat.IndentNestedConditions;

		checkNewLineAfterGroupItem.Checked := GroupByFormat.NewLineAfterItem;

		checkNewLineHavingTop.Checked :=
			HavingFormat.NewLineAfter in [nlAllLogical, nlTopmostOr, nlTopmostLogical];
		checkNewLineHavingTopClick(nil);
		checkNewLineHavingRest.Checked := HavingFormat.NewLineAfter = nlAllLogical;
		checkNewLineHavingRestClick(nil);
		editHavingIndent.Value := HavingFormat.IndentNestedConditions;
	end;
end;

procedure TfmSQLBuilderOptions.SaveSettings;
begin
	with SelectFormat do begin

		MainPartsFromNewLine := checkPartsFromNewLines.Checked;
		NewLineAfterPartKeywords := checkNewLineAfterKeywords.Checked;
		IndentInPart := editPartIndent.Value;
      IndentGlobal := editGlobalIndent.Value;

		SelectListFormat.NewLineAfterItem := checkNewLineAfterSelectItem.Checked;

		FromClauseFormat.NewLineAfterDatasource := checkNewLineAfterDatasource.Checked;
		FromClauseFormat.NewLineAfterJoin := checkNewLineAfterJoin.Checked;

		if checkNewLineWhereRest.Checked
			then WhereFormat.NewLineAfter := nlAllLogical
		else if checkNewLineWhereTop.Checked
			then WhereFormat.NewLineAfter := nlTopmostLogical
			else WhereFormat.NewLineAfter := nlNone;
		WhereFormat.IndentNestedConditions := editWhereIndent.Value;

		checkNewLineAfterGroupItem.Checked := GroupByFormat.NewLineAfterItem;

		if checkNewLineHavingRest.Checked
			then HavingFormat.NewLineAfter := nlAllLogical
		else if checkNewLineHavingTop.Checked
			then HavingFormat.NewLineAfter := nlTopmostLogical
			else HavingFormat.NewLineAfter := nlNone;
		HavingFormat.IndentNestedConditions := editHavingIndent.Value;
	end;
end;

procedure TfmSQLBuilderOptions.checkNewLineWhereTopClick(Sender: TObject);
begin
	checkNewLineWhereRest.Enabled := checkNewLineWhereTop.Checked;
	if not checkNewLineWhereTop.Checked
	then begin
		checkNewLineWhereRest.Checked := False;
		checkNewLineWhereRestClick(Sender);
	end;
end;

procedure TfmSQLBuilderOptions.checkNewLineWhereRestClick(Sender: TObject);
begin
	editWhereIndent.Enabled := checkNewLineWhereRest.Checked;
end;

procedure TfmSQLBuilderOptions.checkNewLineHavingTopClick(Sender: TObject);
begin
	checkNewLineHavingRest.Enabled := checkNewLineHavingTop.Checked;
	if not checkNewLineHavingTop.Checked
	then begin
		checkNewLineHavingRest.Checked := False;
		checkNewLineHavingRestClick(Sender);
	end;
end;

procedure TfmSQLBuilderOptions.checkNewLineHavingRestClick(Sender: TObject);
begin
	editHavingIndent.Enabled := checkNewLineHavingRest.Checked;
end;

end.
